==> openmw_0.48.0.orig.tar.gz: openmw-openmw-0.48.0/components/esm4/loadammo.hpp <==
/*
  Copyright (C) 2016, 2018-2020 cc9cii

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

  cc9cii cc9c@iinet.net.au

  Much of the information on the data structures are based on the information
  from Tes4Mod:Mod_File_Format and Tes5Mod:File_Formats but also refined by
  trial & error.  See http://en.uesp.net/wiki for details.

*/
#ifndef ESM4_AMMO_H
#define ESM4_AMMO_H

#include <cstdint>
#include <string>

#include "formid.hpp"

namespace ESM4
{
    class Reader;
    class Writer;

    struct Ammunition
    {
        struct Data // FIXME: TES5 projectile, damage (float)
        {
            float         speed;
            std::uint32_t flags;
            std::uint32_t value;   // gold
            float         weight;
            std::uint16_t damage;
            std::uint8_t  clipRounds; // only in FO3/FONV

            Data() : speed(0.f), flags(0), value(0), weight(0.f), damage(0), clipRounds(0) {}
        };

        FormId mFormId;       // from the header
        std::uint32_t mFlags; // from the header, see enum type RecordFlag for details

        std::string mEditorId;
        std::string mFullName;
        std::string mModel;
        std::string mText;
        std::string mIcon; // inventory
        std::string mMiniIcon; // inventory

        FormId mPickUpSound;
        FormId mDropSound;

        float mBoundRadius;

        std::uint16_t mEnchantmentPoints;
        FormId mEnchantment;

        Data mData;

        void load(ESM4::Reader& reader);
        //void save(ESM4::Writer& writer) const;

        //void blank();
    };
}

#endif // ESM4_AMMO_H

==> openmw_0.49.0.orig.tar.gz: openmw-openmw-0.49.0/components/esm4/loadammo.hpp <==
/*
  Copyright (C) 2016, 2018-2020 cc9cii

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

  cc9cii cc9c@iinet.net.au

  Much of the information on the data structures are based on the information
  from Tes4Mod:Mod_File_Format and Tes5Mod:File_Formats but also refined by
  trial & error.  See http://en.uesp.net/wiki for details.

*/
#ifndef ESM4_AMMO_H
#define ESM4_AMMO_H

#include <cstdint>
#include <string>
#include <vector>

#include <components/esm/defs.hpp>
#include <components/esm/formid.hpp>

namespace ESM4
{
    class Reader;
    class Writer;

    struct Ammunition
    {
        struct Data
        {
            float mSpeed{ 0.f };
            std::uint32_t mFlags{ 0u };
            std::uint32_t mValue{ 0u };
            float mWeight{ 0.f };
            float mDamage{ 0.f };
            std::uint8_t mClipRounds{ 0u };
            std::uint32_t mProjPerShot{ 0u };
            ESM::FormId mProjectile;
            ESM::FormId mConsumedAmmo;
            float mConsumedPercentage{ 0.f };
            std::uint32_t mHealth{ 0u };
        };

        ESM::FormId mId; // from the header
        std::uint32_t mFlags; // from the header, see enum type RecordFlag for details

        std::string mEditorId;
        std::string mFullName;
        std::string mShortName;
        std::string mAbbrev;
        std::string mModel;
        std::string mText;
        std::string mIcon; // inventory
        std::string mMiniIcon; // inventory

        ESM::FormId mPickUpSound;
        ESM::FormId mDropSound;

        float mBoundRadius;

        std::uint16_t mEnchantmentPoints;
        ESM::FormId mEnchantment;

        std::vector<ESM::FormId> mAmmoEffects;

        ESM::FormId mScript;

        Data mData;

        void load(ESM4::Reader& reader);
        // void save(ESM4::Writer& writer) const;

        // void blank();
        static constexpr ESM::RecNameInts sRecordId = ESM::RecNameInts::REC_AMMO4;
    };
}

#endif // ESM4_AMMO_H
